==> claromentis-framework-9.6.6-26891208.zip: web/intranet/people/classes/UseCase/GetRole.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array("_94c782c8180" . "766e1ff18709" . "75a93053d" => base64_decode("Um9sZSBub3QgZm91bmQ" . "="), "_f4532747e1604" . "b7bf86d299f9b9" . "b0583" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1pc3Npb24gdG8gdmlldyB0aGl" . "zIHJvbGU="));
use Claromentis\Core\ORM\Exceptions\EntityNotFoundException;
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\RoleFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;




class GetRole
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $repository;
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_8652ba33e6ffeba02459fa9cbb320851)
    {
        $this->acl = $acl;
        $this->repository = $_8652ba33e6ffeba02459fa9cbb320851;
    }
    
    
    
    
    
    
    
    
    
    public function GetRole(SecurityContext $context, int $role_id, ?RoleFilter $_03e9164d0a343b742df4793268b80767 = null) : Role
    {
        $_03e9164d0a343b742df4793268b80767 = $_03e9164d0a343b742df4793268b80767 ?? new RoleFilter($context);
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->repository->findOneWithFilter($role_id, $_03e9164d0a343b742df4793268b80767);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_94c782c8180766e1ff18709" . "75a93053d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_f4532747e1604b7bf86d2" . "99f9b9b0583"]);
        }
        return $_d1071a032215f0eb5c4a8ef175f7049d;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/people/classes/UseCase/GetRole.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] ?: array()) + array("_94c782c818076" . "6e1ff1870975a9" . "3053d" => base64_decode("Um9sZSBub3QgZm91" . "bmQ="), "_f4532747e1604b7bf86" . "d299f9b9b0583" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1pc" . "3Npb24gdG8gdmlldyB0aGlzIHJvbG" . "U="));
use Claromentis\Core\ORM\Exceptions\EntityNotFoundException;
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\RoleFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;




class GetRole
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $repository;
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_8652ba33e6ffeba02459fa9cbb320851)
    {
        $this->acl = $acl;
        $this->repository = $_8652ba33e6ffeba02459fa9cbb320851;
    }
    
    
    
    
    
    
    
    
    
    public function GetRole(SecurityContext $context, int $role_id, ?RoleFilter $_03e9164d0a343b742df4793268b80767 = null) : Role
    {
        $_03e9164d0a343b742df4793268b80767 = $_03e9164d0a343b742df4793268b80767 ?? new RoleFilter($context);
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->repository->findOneWithFilter($role_id, $_03e9164d0a343b742df4793268b80767);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_94c782c818" . "0766e1ff187" . "0975a93053d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_f4532747e1604b7b" . "f86d299f9b9b0583"]);
        }
        return $_d1071a032215f0eb5c4a8ef175f7049d;
    }
}
